@@ -45,37 +45,32 @@ impl<'b, A> Clone for AnnotRow<'b, A> {
 // AnnotRow is always `Copy`, regardless of whether or not `A` is.
 impl<'b, A> Copy for AnnotRow<'b, A> {}
 
-/// An `AnnotBlock` with no annotations.
-// TODO: Possibly rename `AnnotBlock` to `Block`
-// #[deprecated(note = "`AnnotBlock<()>` is much more explicit")]
-pub type Block = AnnotBlock<()>;
-
 /// A block of [`Row`], each of which can be given an annotation of any type.  Blocks can start
 /// from any [`Row`], and can be empty.
 ///
 /// All blocks must finish with a 'left-over' [`Row`].  This [`Row`] denotes the first [`Row`] of
-/// any block rung **after** this one.  This is not considered part of the `AnnotBlock`, and
+/// any block rung **after** this one.  This is not considered part of the `Block`, and
 /// therefore cannot be annotated.  However, it is necessary - for example, if we create a `Block`
 /// for the first lead of Cambridge and Primrose Surprise Minor then they would be identical except
 /// for their 'left-over' row.
 #[derive(Clone, Eq, PartialEq, Hash)]
-pub struct AnnotBlock<A> {
+pub struct Block<A> {
     /// The [`Row`]s making up this `Block`.
     ///
     /// **Invariant**: `row.len() >= 1`
     rows: SameStageVec,
-    /// The annotations on each [`Row`] in this `AnnotBlock`.
+    /// The annotations on each [`Row`] in this `Block`.
     ///
     /// **Invariant**: `rows.len() = annots.len() + 1`, because the 'left-over' row cannot be annotated.
     annots: Vec<A>,
 }
 
-impl<A> AnnotBlock<A> {
+impl<A> Block<A> {
     //////////////////
     // CONSTRUCTORS //
     //////////////////
 
-    /// Parse a multi-line [`str`]ing into an `AnnotBlock`, where each row is given the annotation
+    /// Parse a multi-line [`str`]ing into an `Block`, where each row is given the annotation
     /// created by `A::default()`.  Each line in the string is interpreted as a [`Row`], with the
     /// last row being 'left-over'.  The [`Stage`] is inferred from the first line.
     pub fn parse(s: &str) -> Result<Self, ParseError>
@@ -93,7 +88,7 @@ impl<A> AnnotBlock<A> {
         }
     }
 
-    /// Creates a new `AnnotBlock` from a [`SameStageVec`], where every annotation is
+    /// Creates a new `Block` from a [`SameStageVec`], where every annotation is
     /// `A::default()`.
     ///
     /// # Panics
@@ -110,7 +105,7 @@ impl<A> AnnotBlock<A> {
         }
     }
 
-    /// Creates a new [`AnnotBlock`] with no annotated [`Row`], and a leftover [`Row`] of
+    /// Creates a new [`Block`] with no annotated [`Row`], and a leftover [`Row`] of
     /// [`RowBuf::rounds`].
     pub fn empty(stage: Stage) -> Self {
         Self {
@@ -119,7 +114,7 @@ impl<A> AnnotBlock<A> {
         }
     }
 
-    /// Create an [`AnnotBlock`] from a [`SameStageVec`] of [`Row`]s, where each annotation is
+    /// Create an [`Block`] from a [`SameStageVec`] of [`Row`]s, where each annotation is
     /// generated by calling a closure on its index within this block.  Returns `None` if the
     /// [`SameStageVec`] contained no [`Row`]s.
     pub fn with_annots_from_indices(rows: SameStageVec, f: impl FnMut(usize) -> A) -> Option<Self> {
@@ -140,8 +135,8 @@ impl<A> AnnotBlock<A> {
         self.rows.stage()
     }
 
-    /// Gets the effective [`Stage`] of this `AnnotBlock` - i.e. the smallest [`Stage`] that this
-    /// `AnnotBlock` can be reduced to without producing invalid [`Row`]s.  See
+    /// Gets the effective [`Stage`] of this `Block` - i.e. the smallest [`Stage`] that this
+    /// `Block` can be reduced to without producing invalid [`Row`]s.  See
     /// [`Row::effective_stage`] for more info and examples.
     pub fn effective_stage(&self) -> Stage {
         self.all_rows()
@@ -195,7 +190,7 @@ impl<A> AnnotBlock<A> {
         Some(AnnotRow::new(row, annot))
     }
 
-    /// Gets the first [`Row`] of this `AnnotBlock`, which may be leftover.
+    /// Gets the first [`Row`] of this `Block`, which may be leftover.
     #[inline]
     pub fn first_row(&self) -> &Row {
         // This `unwrap` won't panic, because we require an invariant that `self.row_buffer` is
@@ -203,7 +198,7 @@ impl<A> AnnotBlock<A> {
         self.rows.first().unwrap()
     }
 
-    /// Gets the first [`Row`] of this `AnnotBlock`, along with its annotation.
+    /// Gets the first [`Row`] of this `Block`, along with its annotation.
     #[inline]
     pub fn first_annot_row(&self) -> Option<AnnotRow<A>> {
         self.get_annot_row(0)
@@ -222,8 +217,8 @@ impl<A> AnnotBlock<A> {
     //////////////////////////////
 
     /// Returns an [`Iterator`] which yields the [`Row`]s which are directly part of this
-    /// `AnnotBlock`.  This does not include the 'left-over' row; if you want to include the
-    /// left-over [`Row`], use [`AnnotBlock::all_rows`] instead.
+    /// `Block`.  This does not include the 'left-over' row; if you want to include the
+    /// left-over [`Row`], use [`Block::all_rows`] instead.
     #[inline]
     pub fn rows(&self) -> same_stage_vec::Iter {
         let mut iter = self.all_rows();
@@ -237,7 +232,7 @@ impl<A> AnnotBlock<A> {
         self.rows.iter()
     }
 
-    /// Returns an [`Iterator`] which yields the annotations of this [`AnnotBlock`], in
+    /// Returns an [`Iterator`] which yields the annotations of this [`Block`], in
     /// sequential order.
     #[inline]
     pub fn annots(&self) -> std::slice::Iter<A> {
@@ -245,8 +240,8 @@ impl<A> AnnotBlock<A> {
     }
 
     /// Returns an [`Iterator`] which yields the [`Row`]s which are directly part of this
-    /// `AnnotBlock`.  This does not include the 'left-over' row; if you want to include the
-    /// left-over [`Row`], use [`AnnotBlock::all_rows`] instead.
+    /// `Block`.  This does not include the 'left-over' row; if you want to include the
+    /// left-over [`Row`], use [`Block::all_rows`] instead.
     #[inline]
     pub fn annot_rows(&self) -> impl Iterator<Item = AnnotRow<A>> + Clone {
         self.rows()
@@ -254,7 +249,7 @@ impl<A> AnnotBlock<A> {
             .map(|(r, a)| AnnotRow::new(r, a))
     }
 
-    /// Returns the places of a given [`Bell`] in each [`Row`] of this `AnnotBlock`.  Also returns
+    /// Returns the places of a given [`Bell`] in each [`Row`] of this `Block`.  Also returns
     /// the place of `bell` in the leftover row.
     pub fn path_of(&self, bell: Bell) -> Option<(Vec<usize>, usize)> {
         let mut full_path = self.full_path_of(bell)?;
@@ -262,7 +257,7 @@ impl<A> AnnotBlock<A> {
         Some((full_path, place_in_leftover_row))
     }
 
-    /// Returns the places of a given [`Bell`] in each [`Row`] of this `AnnotBlock`, **including**
+    /// Returns the places of a given [`Bell`] in each [`Row`] of this `Block`, **including**
     /// the leftover row.
     pub fn full_path_of(&self, bell: Bell) -> Option<Vec<usize>> {
         self.rows.path_of(bell) // Delegate to `SameStageVec`
@@ -295,7 +290,7 @@ impl<A> AnnotBlock<A> {
         self.rows.pre_multiply(lhs_row) // Delegate to `SameStageVec`
     }
 
-    /// Extends `self` with the contents of another [`AnnotBlock`], **pre-multiplying** its [`Row`]s so
+    /// Extends `self` with the contents of another [`Block`], **pre-multiplying** its [`Row`]s so
     /// that it starts with `self`'s [`leftover_row`](Self::leftover_row).
     pub fn extend(&mut self, other: &Self) -> Result<(), IncompatibleStages>
     where
@@ -304,7 +299,7 @@ impl<A> AnnotBlock<A> {
         self.extend_range(other, ..)
     }
 
-    /// Extends `self` with a region of another [`AnnotBlock`], **pre-multiplying** its [`Row`]s so
+    /// Extends `self` with a region of another [`Block`], **pre-multiplying** its [`Row`]s so
     /// that it starts with `self`'s [`leftover_row`](Self::leftover_row).
     ///
     /// # Panics
@@ -366,31 +361,31 @@ impl<A> AnnotBlock<A> {
     // OPERATIONS WHICH CONSUME SELF //
     ///////////////////////////////////
 
-    /// Consumes this `AnnotBlock`, and returns a [`SameStageVec`] containing the same [`Row`]s,
+    /// Consumes this `Block`, and returns a [`SameStageVec`] containing the same [`Row`]s,
     /// **including** the left-over row.
     pub fn into_row_vec(self) -> SameStageVec {
         self.rows
     }
 
-    /// Borrows the [`SameStageVec`] which contains all the [`Row`]s in this `AnnotBlock`
+    /// Borrows the [`SameStageVec`] which contains all the [`Row`]s in this `Block`
     pub fn row_vec(&self) -> &SameStageVec {
         &self.rows
     }
 
-    /// Convert this `AnnotBlock` into another `AnnotBlock` with identical [`Row`]s, but where each
+    /// Convert this `Block` into another `Block` with identical [`Row`]s, but where each
     /// annotation is passed through the given function.
-    pub fn map_annots<B>(self, f: impl Fn(A) -> B) -> AnnotBlock<B> {
-        AnnotBlock {
+    pub fn map_annots<B>(self, f: impl Fn(A) -> B) -> Block<B> {
+        Block {
             rows: self.rows, // Don't modify the rows
             annots: self.annots.into_iter().map(f).collect_vec(),
         }
     }
 
-    /// Convert this `AnnotBlock` into another `AnnotBlock` with identical [`Row`]s, but where each
+    /// Convert this `Block` into another `Block` with identical [`Row`]s, but where each
     /// annotation is passed through the given function (along with its index within the
-    /// `AnnotBlock`).
-    pub fn map_annots_with_index<B>(self, f: impl Fn(usize, A) -> B) -> AnnotBlock<B> {
-        AnnotBlock {
+    /// `Block`).
+    pub fn map_annots_with_index<B>(self, f: impl Fn(usize, A) -> B) -> Block<B> {
+        Block {
             rows: self.rows, // Don't modify the rows
             annots: self
                 .annots
@@ -401,14 +396,11 @@ impl<A> AnnotBlock<A> {
         }
     }
 
-    /// Convert this `AnnotBlock` into another `AnnotBlock` with identical [`Row`]s, but where each
+    /// Convert this `Block` into another `Block` with identical [`Row`]s, but where each
     /// annotation is passed through the given function (along with its index within the
-    /// `AnnotBlock`).
-    pub fn clone_map_annots_with_index<'s, B>(
-        &'s self,
-        f: impl Fn(usize, &'s A) -> B,
-    ) -> AnnotBlock<B> {
-        AnnotBlock {
+    /// `Block`).
+    pub fn clone_map_annots_with_index<'s, B>(&'s self, f: impl Fn(usize, &'s A) -> B) -> Block<B> {
+        Block {
             rows: self.rows.to_owned(), // Don't modify the rows
             annots: self
                 .annots
@@ -419,9 +411,9 @@ impl<A> AnnotBlock<A> {
         }
     }
 
-    /// Splits this `AnnotBlock` into two separate `AnnotBlock`s at a specified index.  This is
-    /// defined such the first `AnnotBlock` has length `index`.  This returns `None` if the second
-    /// `AnnotBlock` would have negative length.
+    /// Splits this `Block` into two separate `Block`s at a specified index.  This is
+    /// defined such the first `Block` has length `index`.  This returns `None` if the second
+    /// `Block` would have negative length.
     pub fn split(self, index: usize) -> Option<(Self, Self)> {
         let (first_annots, second_annots) = utils::split_vec(self.annots, index)?;
         let (mut first_rows, second_rows) = self.rows.split(index)?;
@@ -449,7 +441,7 @@ impl<A> AnnotBlock<A> {
 // FORMATTING //
 ////////////////
 
-impl<T> Debug for AnnotBlock<T>
+impl<T> Debug for Block<T>
 where
     T: Debug,
 {
@@ -467,7 +459,7 @@ where
             }
         }
 
-        let mut builder = f.debug_tuple(stringify!(AnnotBlock));
+        let mut builder = f.debug_tuple(stringify!(Block));
         for annot_row in self.annot_rows() {
             // Format all annotated rows as `row: annot`
             builder.field(&Pair(DbgRow(annot_row.row()), annot_row.annot()));
@@ -481,22 +473,22 @@ where
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /// Iterator used internally by [`RepeatIter`], which yields the (&Row, &annotation) pairs from an
-/// [`AnnotBlock`].
+/// [`Block`].
 type InnerIter<'b, A> =
     std::iter::Enumerate<itertools::ZipEq<same_stage_vec::Iter<'b>, slice::Iter<'b, A>>>;
 
-/// An [`Iterator`] which yields an [`AnnotBlock`] forever.  Created with
-/// [`AnnotBlock::repeat_iter`].
+/// An [`Iterator`] which yields an [`Block`] forever.  Created with
+/// [`Block::repeat_iter`].
 #[derive(Clone)]
 pub struct RepeatIter<'b, A> {
     /// Invariant: `self.current_block_head` must have the same [`Stage`] as `self.block`
     current_block_head: RowBuf,
     iter: InnerIter<'b, A>,
-    block: &'b AnnotBlock<A>,
+    block: &'b Block<A>,
 }
 
 impl<'b, A> RepeatIter<'b, A> {
-    fn new(start_row: RowBuf, block: &'b AnnotBlock<A>) -> Result<Self, IncompatibleStages> {
+    fn new(start_row: RowBuf, block: &'b Block<A>) -> Result<Self, IncompatibleStages> {
         IncompatibleStages::test_err(start_row.stage(), block.stage())?;
         Ok(Self {
             current_block_head: start_row,
@@ -515,7 +507,7 @@ impl<'b, A> RepeatIter<'b, A> {
         Some((source_idx, annot))
     }
 
-    fn get_iter(block: &'b AnnotBlock<A>) -> InnerIter<'b, A> {
+    fn get_iter(block: &'b Block<A>) -> InnerIter<'b, A> {
         block.rows().zip_eq(block.annots()).enumerate()
     }
 
@@ -544,7 +536,7 @@ impl<'b, A> Iterator for RepeatIter<'b, A> {
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
-/// The possible ways that [`AnnotBlock::parse`] could fail
+/// The possible ways that [`Block::parse`] could fail
 #[derive(Debug, Clone)]
 pub enum ParseError {
     ZeroLengthBlock,
