@@ -6,7 +6,7 @@ use std::{
 
 use itertools::Itertools;
 
-use crate::{AnnotBlock, Bell, PlaceNot, Stage};
+use crate::{Bell, Block, PlaceNot, Stage};
 
 // Imports used solely for doc comments
 #[allow(unused_imports)]
@@ -31,8 +31,8 @@ impl FullClass {
         }
     }
 
-    /// Compute the [`FullClass`] of a [`Method`], given an [`AnnotBlock`] representing its first lead.
-    pub fn classify<A>(first_lead: &AnnotBlock<A>) -> FullClass {
+    /// Compute the [`FullClass`] of a [`Method`], given an [`Block`] representing its first lead.
+    pub fn classify<A>(first_lead: &Block<A>) -> FullClass {
         classify(first_lead) // Delegate to the helper function
     }
 
@@ -254,7 +254,7 @@ impl Display for Class {
 /////////////////////////
 
 /// Classify a method, given its first lead
-fn classify<A>(first_lead: &AnnotBlock<A>) -> FullClass {
+fn classify<A>(first_lead: &Block<A>) -> FullClass {
     let stage = first_lead.stage();
 
     // Generate hunt & working bell cycles, and their paths
@@ -416,7 +416,7 @@ fn classify_hunt_cycle(cycle: &Cycle, stage: Stage) -> (bool, HuntBellClass) {
 }
 
 /// Given a Treble Bob method, sub-classify it into either Surprise, Delight or Treble Bob
-fn sub_classify_treble_dodging<A>(first_lead: &AnnotBlock<A>, hunt_cycles: &[&Cycle]) -> Class {
+fn sub_classify_treble_dodging<A>(first_lead: &Block<A>, hunt_cycles: &[&Cycle]) -> Class {
     let mut cross_indices = HashSet::<usize>::new();
     // Use the hunt bell paths to figure out in which places the hunt bells hunt between dodges
     for &cycle in hunt_cycles {
@@ -498,12 +498,12 @@ fn is_palindromic(path: &[usize]) -> bool {
 #[derive(Debug, Clone)]
 struct Cycle {
     place_bells: Vec<Bell>,
-    full_path: Vec<usize>,
+    full_path: Vec<usize>, // TODO: Make these Vec<u8>, because places >255 are impossible
 }
 
 impl Cycle {
     /// Returns all the cycles generated by repeating a given `lead`
-    fn cycles_from_lead<A>(first_lead: &AnnotBlock<A>) -> Vec<Self> {
+    fn cycles_from_lead<A>(first_lead: &Block<A>) -> Vec<Self> {
         // Check that the lead starts from rounds
         assert!(first_lead.first_annot_row().unwrap().row().is_rounds());
 
@@ -512,7 +512,7 @@ impl Cycle {
 
         // Repeatedly follow cycles until every bell is in a cycle that we've already explored
         while let Some(starting_bell_idx) = bells_left.iter().position(|v| *v) {
-            let starting_bell = Bell::from_index(starting_bell_idx);
+            let starting_bell = Bell::from_index(starting_bell_idx as u8);
             let mut place_bells_in_cycle = Vec::new();
             let mut full_path = Vec::new();
             // Follow the cycle which contains `starting_bell_idx`, marking those bells as
@@ -527,7 +527,7 @@ impl Cycle {
                 place_bells_in_cycle.push(place_bell);
                 full_path.extend(path);
                 // Move to the next place bell, and
-                place_bell = Bell::from_index(next_place_bell);
+                place_bell = Bell::from_index(next_place_bell as u8);
                 if place_bell == starting_bell {
                     break;
                 }
@@ -581,7 +581,7 @@ mod tests {
     fn classification() {
         let mut num_misclassifications = 0usize;
         for (name, pn, class) in MethodLib::cc_lib().unwrap().all_pns_and_classes() {
-            let plain_lead: Block = pn.to_block_from_rounds();
+            let plain_lead: Block<()> = pn.to_block_from_rounds();
             let computed_class = FullClass::classify(&plain_lead);
             if computed_class != class {
                 println!(
